
/* special structure, used only by art_name_array[] */

typedef struct namebytype {
  char *name; /* generic name to call artifacts of this type */
  int type;   /* matching type */
} arttypename;


/* these are needed for creation of a linked list of
 * pointers to all (hostile) monster objects */

static int nrofmon=0;
static objectlink *first_mon_info;


/* this is needed to keep track of status of initialization
 * of the message file */ 
static int nrofmsg=0;
static linked_char *first_msg;


static uint32 spellpathdef[NRSPELLPATHS] = {
  PATH_PROT,
  PATH_FIRE,
  PATH_FROST,
  PATH_ELEC,
  PATH_MISSILE,
  PATH_SELF,
  PATH_SUMMON,
  PATH_ABJURE,
  PATH_RESTORE,
  PATH_DETONATE,
  PATH_MIND,
  PATH_CREATE,
  PATH_TELE,
  PATH_INFO,
  PATH_TRANSMUTE,
  PATH_TRANSFER,
  PATH_TURNING,
  PATH_WOUNDING,
  PATH_DEATH,
  PATH_LIGHT
};

/* if it isnt listed here, then art_attr_msg will never generate
 * a message for this type of artifact. -b.t. */

static arttypename art_name_array[] = {
  {"Helmet", HELMET},
  {"Amulet", AMULET},
  {"Shield", SHIELD},
  {"Bracers", BRACERS},
  {"Boots", BOOTS},
  {"Cloak", CLOAK},
  {"Gloves", GLOVES},
  {"Gridle", GIRDLE},
  {"Ring", RING},
  {"Horn", HORN},
  {"Missile Weapon", BOW},
  {"Missile", ARROW},
  {"Hand Weapon", WEAPON},
  {"Artifact", SKILL},
  {"Food", FOOD},
  {"Body Armour", ARMOUR}
};

static char *mon_book_name[] = {
  "beastuary",
  "catalog",
  "compilation",
  "collection",
  "encyclopedia",
  "guide",
  "handbook",
  "list",
  "manual",
  "notes",
  "record",
  "register",
  "volume"
}; 

static char *art_book_name[] = {
  "collection",
  "file",
  "files",
  "guide",
  "handbook",
  "index",
  "inventory",
  "list",
  "listing",
  "record",
  "record book"
};

static char *gods_book_name[] = {
  "devotional",
  "devout notes",
  "divine text",
  "divine work",
  "holy book",
  "holy record",
  "moral text",
  "sacred guide",
  "testament",
  "transcript"
};

static char *path_book_name[] = {
  "codex",
  "compendium", 
  "exposition",
  "tables",
  "treatise"
};

static char *formula_book_name[] = {
  "cookbook", 
  "formulary",
  "handbook",
  "lab book", 
  "lab notes",
  "recipe book"
};

/* used by msg file and 'generic' books */
static char *light_book_name[] = {
  "calendar",
  "datebook",
  "diary",
  "guidebook",
  "handbook",
  "ledger",
  "notes",
  "notebook",
  "octavo",
  "pamphlet",
  "practicum",
  "script",
  "transcript"
};
 
static char *heavy_book_name[] = {
  "catalog", 
  "compendium",
  "guide",
  "manual", 
  "opus", 
  "tome",
  "treatise",
  "volume", 
  "work"  
};

#if 0
static char *book_name[] = {
  "calendar",
  "catalog",
  "compendium",
  "datebook",
  "diary",
  "guide",
  "guidebook",
  "ledger",
  "letter",
  "librum",
  "manual",
  "notes",
  "notebook",
  "octavo",
  "opus",
  "pamphlet",
  "practicum",
  "script",
  "tome",
  "transcript", 
  "treatise",
  "volume",
  "work"
};
#endif

/* used by gods texts */
static char *gods_author[] = {
  "cults",
  "joy",
  "lasting curse",
  "madness",
  "religions",
  "the dead",
  "the gods",
  "the heirophant", 
  "the poor priest",
  "the priestess",
  "pain",
  "white"
};

/* used by monster beastuary texts */
static char *mon_author[] = {
  "beasts",  
  "creatures", 
  "dezidens",
  "dwellers",
  "evil nature",
  "life",
  "monsters",
  "nature",
  "new life", 
  "residents",
  "the spawn",
  "the living",
  "things"
};

/* used by alchemical texts */
static char *formula_author[] = {
  "Albertus Magnus",
  "alchemy",
  "balms",
  "creation",
  "dusts",
  "magical manufacture",
  "making",
  "philosophical items",
  "potions",
  "powders",
  "the cauldron",
  "the lamp black",
  "transmutation",
  "waters"
};

/* used by artifact texts */
static char *art_author[] = {
  "ancient things",
  "artifacts",
  "Havlor", /* ancient warrior scribe :) */
  "items",
  "lost artifacts",
  "the ancients",
  "useful things"
};

/* used by spellpath texts */
static char *path_author[] = {
  "aether", 
  "astral byways", 
  "connections", 
  "the Grey Council",
  "deep pathways",
  "knowledge",
  "magic",
  "mystic ways",
  "pathways",
  "power",
  "spells",
  "transforms", 
  "the mystic veil",
  "unknown spells"
};

/* used by 'generic' books */
static char *book_author[] = {
  "Abdulah",
  "Al'hezred",
  "Alywn",
  "Arundel",
  "Arvind",
  "Aerlingas",
  "Bacon",
  "Baliqendii",
  "Bosworth",
  "Beathis",
  "Bertil",
  "Cauchy",
  "Chakrabarti",
  "der Waalis",
  "Dirk",
  "Djwimii",
  "Eisenstaadt",
  "Fendris",
  "Frank",
  "Habbi",
  "Harlod",
  "Ichibod",
  "Janus",
  "June",
  "Magnuson",
  "Nandii",
  "Nitfeder",
  "Norris",
  "Parael",
  "Penhew",
  "Sophia",
  "Skilly",
  "Tahir",
  "Thockmorton",
  "Thomas",
  "van Helsing",
  "van Pelt",
  "Voormis",
  "Xavier",
  "Xeno",
  "Zardoz",
  "Zagy"
};

static char *book_descrpt[] = {
  "ancient",
  "cryptic",
  "cryptical",
  "dusty",
  "hiearchical",
  "grizzled",
  "gold-guilt",
  "great",
  "lost",
  "magnificent",
  "musty",
  "mythical",
  "mystical",
  "rustic",
  "stained",
  "silvered",
  "transcendental",
  "weathered"
};

static char *mage_book_name[] = { 
  "grimore",
  "grimore",
  "grimore",
  "manual",
  "tome",
  "treatise"
};

static char *priest_book_name[] = {   
  "hymnal",
  "prayerbook",
  "prayerbook",
  "prayerbook",
  "sacred text",
  "testiment"
};

